fn create_target_view_sql(
stmt: &Statement,
fqn: &FullyQualifiedName,
) -> Result<String, String>Expand description
Create SQL for the target view as a temporary view with flattened naming.
Returns an error if the target statement is not a CREATE VIEW or
CREATE MATERIALIZED VIEW — unit tests only apply to those object types.